@@ -5,6 +5,7 @@ License: GPL 2.0
 */
 #include "ccextractor.h"
 #include <stdio.h>
+#include <locale.h>
 
 volatile int terminate_asap = 0;
 
@@ -122,7 +123,7 @@ int api_start(struct ccx_s_options api_options)
             switch (ctx->total_inputsize)
             {
                 case -1*ENOENT:
-                    fatal(EXIT_NO_INPUT_FILES, "Failed to open input file: File does not exist.");
+                    fatal(EXIT_NO_INPUT_FILES, "Failed to open one of the input file(s): File does not exist.");
                 case -1*EACCES:
                     fatal(EXIT_READ_ERROR, "Failed to open input file: Unable to access");
                 case -1*EINVAL:
@@ -282,7 +283,7 @@ int api_start(struct ccx_s_options api_options)
                         total_frames_count, current_fps);
             }
 
-            if (ctx->stat_hdtv)
+            if (dec_ctx->stat_hdtv)
             {
                 mprint ("\rCC type 0: %d (%s)\n", dec_ctx->cc_stats[0], cc_types[0]);
                 mprint ("CC type 1: %d (%s)\n", dec_ctx->cc_stats[1], cc_types[1]);
@@ -502,6 +503,7 @@ int api_param_count(struct ccx_s_options* api_options)
 
 int main(int argc, char* argv[])
 {
+    setlocale(LC_ALL, "");
     struct ccx_s_options* api_options = api_init_options();
     check_configuration_file(*api_options);
 #ifdef PYTHON_API
