@@ -1,6 +1,5 @@
 #include "png.h"
 #include "protobuf-c.h"
-#include "utf8proc/utf8proc.h"
 #include "zlib.h"
 #include "gpac/version.h"
 #include "lib_ccx.h"
@@ -14,9 +13,10 @@
 #include "../lib_hash/sha2.h"
 #include <string.h>
 #include <stdio.h>
+#include "utf8proc/utf8proc.h"
 
 #ifdef ENABLE_OCR
-#include "capi.h"
+#include "tesseract/capi.h"
 #include "allheaders.h"
 #endif
 
@@ -28,7 +28,7 @@
 #define DEFAULT_FONT_PATH "C:\\Windows\\Fonts\\calibri.ttf"
 #elif __APPLE__ // MacOS
 #define DEFAULT_FONT_PATH "/System/Library/Fonts/Helvetica.ttc"
-#else // Assume linux
+#else // Assume Linux
 #define DEFAULT_FONT_PATH "/usr/share/fonts/truetype/noto/NotoSans-Regular.ttf"
 #endif
 
@@ -114,6 +114,8 @@ int parsedelay (struct ccx_s_options *opt, char *par)
 
 int append_file_to_queue (struct ccx_s_options *opt,char *filename)
 {
+	if(filename[0] == '\0') //skip files with empty file name (ex : ./ccextractor "")
+		return 0;
 	char *c=(char *) malloc (strlen (filename)+1);
 	if (c==NULL)
 		return -1;
@@ -414,7 +416,7 @@ void print_usage (void)
 #ifdef WTV_DEBUG
 	mprint ("                       hex  -> Hexadecimal dump as generated by wtvccdump.\n");
 #endif
-	mprint ("       -ts, -ps, -es, -mp4, -wtv and -asf (or --dvr-ms) can be used as shorts.\n\n");
+	mprint ("       -ts, -ps, -es, -mp4, -wtv, -mkv and -asf/--dvr-ms can be used as shorts.\n\n");
 	mprint ("Output formats:\n\n");
 	mprint ("                 -out=format\n\n");
 	mprint ("       where format is one of these:\n");
@@ -430,6 +432,12 @@ void print_usage (void)
 	mprint ("                                 captions, just the plain transcription.\n");
 	mprint ("                      ttxt    -> Timed Transcript (transcription with time\n");
 	mprint ("                                 info)\n");
+	mprint ("                      g608    -> Grid 608 format.\n");
+#ifdef WITH_LIBCURL
+	mprint ("                      curl    -> POST plain transcription frame-by-frame to a\n");
+	mprint ("                                 URL specified by -curlposturl. Don't produce\n");
+	mprint ("                                 any file output.\n");
+#endif
 	mprint ("                      smptett -> SMPTE Timed Text (W3C TTML) format.\n");
 	mprint ("                      spupng  -> Set of .xml and .png files for use with\n");
 	mprint ("                                 dvdauthor's spumux.\n");
@@ -438,6 +446,7 @@ void print_usage (void)
 	mprint ("                      report  -> Prints to stdout information about captions\n");
 	mprint ("                                 in specified input. Don't produce any file\n");
 	mprint ("                                 output\n\n");
+	mprint ("       -srt, -dvdraw, -sami, -webvtt, -txt, -ttxt and -null can be used as shorts.\n\n");
 
 	mprint ("Options that affect how input files will be processed.\n");
 
@@ -495,6 +504,7 @@ void print_usage (void)
 	mprint ("                       -autoprogram (see below) is used.\n");
 	mprint ("         -autoprogram: If there's more than one program in the stream, just use\n");
 	mprint ("                       the first one we find that contains a suitable stream.\n");
+	mprint ("        -multiprogram: Uses multiple programs from the same input stream.\n");
 	mprint ("             -datapid: Don't try to find out the stream for caption/teletext\n");
 	mprint ("                       data, just use this one instead.\n");
 	mprint ("      -datastreamtype: Instead of selecting the stream by its PID, select it\n");
@@ -604,6 +614,10 @@ void print_usage (void)
 	mprint ("                       free to play with it but be aware that this format\n");
 	mprint ("                       is really live - don't rely on its output format\n");
 	mprint ("                       not changing between versions.\n");
+    mprint ("            -latrusmap Map Latin symbols to Cyrillic ones in special cases\n");
+    mprint ("                       of Russian Teletext files (issue #1086)\n");
+    mprint ("                 -xds: In timed transcripts, all XDS information will be saved\n");
+	mprint ("                       to the output file.\n");
 	mprint ("                  -lf: Use LF (UNIX) instead of CRLF (DOS, Windows) as line\n");
 	mprint ("                       terminator.\n");
 	mprint ("            -autodash: Based on position on screen, attempt to determine\n");
@@ -612,6 +626,9 @@ void print_usage (void)
 	mprint ("          -xmltv mode: produce an XMLTV file containing the EPG data from\n");
 	mprint ("                       the source TS file. Mode: 1 = full output\n");
 	mprint ("                       2 = live output. 3 = both\n");
+	mprint (" -xmltvliveinterval x: interval of x seconds between writing live mode xmltv output.\n");
+	mprint ("-xmltvoutputinterval x: interval of x seconds between writing full file xmltv output.\n");
+	mprint ("    -xmltvonlycurrent: Only print current events for xmltv output.\n");
 	mprint ("                 -sem: Create a .sem file for each output file that is open\n");
 	mprint ("                       and delete it on file close.\n");
 	mprint ("             -dvblang: For DVB subtitles, select which language's caption\n");
@@ -881,6 +898,9 @@ void print_usage (void)
 	mprint("         NOTE: The following options will work only if -hardsubx is \n");
 	mprint("                specified before them:-\n");
 	mprint("\n");
+	mprint("       -tickertext : Search for burned-in ticker text at the bottom of\n");
+	mprint("                     the screen.\n");
+	mprint("\n");
 	mprint("         -ocr_mode : Set the OCR mode to either frame-wise, word-wise\n");
 	mprint("                     or letter wise.\n");
 	mprint("                     e.g. -ocr_mode frame (default), -ocr_mode word, \n");
@@ -1950,7 +1970,7 @@ int parse_parameters (struct ccx_s_options *opt, int argc, char *argv[])
 		}
 		if (strcmp (argv[i],"-xds")==0)
 		{
-			// XDS can be set regardless of -UCLA (isFinal) usage.
+            // XDS can be set regardless of -UCLA (isFinal) usage.
 			opt->transcript_settings.xds = 1;
 			continue;
 		}
@@ -2125,6 +2145,11 @@ int parse_parameters (struct ccx_s_options *opt, int argc, char *argv[])
 			}
 			continue;
 		}
+        if (strcmp (argv[i],"-latrusmap")==0 )
+        {
+            tlt_config.latrusmap = 1;
+            continue;
+        }
 		if (strcmp (argv[i],"-tickertext")==0 || strcmp (argv[i],"-tickertape")==0)
 		{
 			opt->tickertext = 1;
